@@ -236,5 +236,6 @@ def plot(
         )
     if add_axes_labels:
         plt.xlabel("Re(z)")
-        plt.ylabel("Im(z)", rotation=0)
+        # ylabel off-center, <https://github.com/matplotlib/matplotlib/issues/21467>
+        plt.ylabel("Im(z)", rotation="horizontal", loc="center", labelpad=10)
     return plt
